@@ -63,6 +63,7 @@ class CompositeType(SerializableType):
         fixed_port_id: typing.Optional[int],
         source_file_path: str,
         has_parent_service: bool,
+        doc: str = "",
     ):
         super().__init__()
 
@@ -75,6 +76,8 @@ class CompositeType(SerializableType):
         self._source_file_path = str(source_file_path)
         self._has_parent_service = bool(has_parent_service)
 
+        self._doc = doc
+
         # Name check
         if not self._name:
             raise InvalidNameError("Composite type name cannot be empty")
@@ -151,6 +154,11 @@ class CompositeType(SerializableType):
         """The last component of the full name, e.g., ``Heartbeat`` of ``uavcan.node.Heartbeat``."""
         return self.name_components[-1]
 
+    @property
+    def doc(self) -> str:
+        """The DSDL header comment provided for this data type without the leading #."""
+        return self._doc
+
     @property
     def full_namespace(self) -> str:
         """The full name without the short name, e.g., ``uavcan.node`` for ``uavcan.node.Heartbeat``."""
@@ -345,6 +353,7 @@ class UnionType(CompositeType):
         fixed_port_id: typing.Optional[int],
         source_file_path: str,
         has_parent_service: bool,
+        doc: str = "",
     ):
         # Proxy all parameters directly to the base type - I wish we could do that
         # with kwargs while preserving the type information
@@ -356,6 +365,7 @@ class UnionType(CompositeType):
             fixed_port_id=fixed_port_id,
             source_file_path=source_file_path,
             has_parent_service=has_parent_service,
+            doc=doc,
         )
 
         if self.number_of_variants < self.MIN_NUMBER_OF_VARIANTS:
@@ -512,6 +522,7 @@ class DelimitedType(CompositeType):
             fixed_port_id=inner.fixed_port_id,
             source_file_path=inner.source_file_path,
             has_parent_service=inner.has_parent_service,
+            doc=inner.doc,
         )
         self._extent = int(extent)
         if self._extent % self.alignment_requirement != 0:
@@ -648,6 +659,7 @@ class ServiceType(CompositeType):
             fixed_port_id=fixed_port_id,
             source_file_path=request.source_file_path,
             has_parent_service=False,
+            doc=request.doc,
         )
 
     @property
